@@ -1,10 +1,9 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 4.21 2009/01/01 16:51:41 bkorb Exp $
+ *  $Id: c2b939af0e5d78a17956ed485b79d6d2be85100e $
  *
- *  Time-stamp:        "2008-07-26 10:00:15 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:51:41 $
+ *  Time-stamp:        "2009-11-01 14:10:47 bkorb"
  *
  *  This is the main routine for autogen.
  *
@@ -53,8 +52,6 @@ strlcpy( char* dest, tCC* src, size_t n )
         }
     }
 
-    assert( sz + (src - ps) == strlen( ps ) + 1 );
-
     return sz + (src - ps);
 }
 #endif
@@ -70,11 +67,9 @@ aprf( char const* pzFmt, ... )
     va_end( ap );
 
     if (pz == NULL) {
-        tSCC zMsg[] = "could not allocate for or formatting failed on:\n";
-        char z[ 256 ];
-        strcpy( z, zMsg );
-        strncpy( z + sizeof( zMsg )-1, pzFmt, sizeof(z) - sizeof(zMsg));
-        z[ sizeof(z)-1 ] = NUL;
+        tSCC zMsg[] = "could not allocate for or formatting failed on:\n%s";
+        char z[ sizeof (zMsg) + SCRIBBLE_SIZE ];
+        snprintf(z, sizeof(z), zMsg, pzFmt);
         AG_ABEND( z );
     }
     return pz;
@@ -172,6 +167,7 @@ doOptions( int arg_ct, char** arg_vec )
          *  Point to the character after the last '/', or to the full
          *  definition file name, if there is no '/'.
          */
+        // coverity[dereference] -- invalid analysis -- "pz" not dereferenced.
         if (pz++ == NULL)
             pz = OPT_ARG( DEFINITIONS );
 
