@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  August  8, 2009 at 10:14:56 AM by AutoGen 5.9.9
+ *  It has been AutoGen-ed  November  8, 2009 at 08:41:21 AM by AutoGen 5.9.10pre13
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
@@ -221,10 +221,13 @@ cgi_run_fsm(
 
         /* END   == FIND TRANSITION == DO NOT CHANGE THIS COMMENT */
 
+#ifndef __COVERITY__
         if (trans_evt >= CGI_EV_INVALID) {
             nxtSt = CGI_ST_INVALID;
             trans = CGI_TR_INVALID;
-        } else {
+        } else
+#endif /* __COVERITY__ */
+        {
             const t_cgi_transition* pTT =
             cgi_trans_table[ cgi_state ] + trans_evt;
             nxtSt = pTT->next_state;
