@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (defParse-fsm.c)
  *  
- *  It has been AutoGen-ed  August  8, 2009 at 10:14:57 AM by AutoGen 5.9.9
+ *  It has been AutoGen-ed  November  8, 2009 at 08:41:21 AM by AutoGen 5.9.10pre13
  *  From the definitions    defParse.def
  *  and the template file   fsm
  *
@@ -386,6 +386,8 @@ dp_do_empty_val(
 
     pDE->val.pzText = nil_pz;
     pDE->valType    = VALTYP_TEXT;
+    if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+        print_def(pDE);
     return maybe_next;
 /*  END   == EMPTY VAL == DO NOT CHANGE THIS COMMENT  */
 }
@@ -515,6 +517,9 @@ dp_do_start_block(
         yyerror( (void*)"assigning a block value to text name" );
     pCurrentEntry->valType = VALTYP_BLOCK; /* in case not yet determined */
 
+    if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+        print_def(pCurrentEntry);
+
     if (++stackDepth >= stackSize) {
         tDefEntry** ppDE;
         stackSize += stackSize / 2;
@@ -547,6 +552,9 @@ dp_do_str_value(
     pCurrentEntry->val.pzText = pz_token;
     pCurrentEntry->valType = VALTYP_TEXT;
 
+    if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+        print_def(pCurrentEntry);
+
     /*
      *  The "here string" marker is the line before where the text starts.
      */
@@ -602,10 +610,13 @@ dp_run_fsm( void )
         trans_evt = yylex();
         /* END   == FIND TRANSITION == DO NOT CHANGE THIS COMMENT */
 
+#ifndef __COVERITY__
         if (trans_evt >= DP_EV_INVALID) {
             nxtSt = DP_ST_INVALID;
             pT    = dp_do_invalid;
-        } else {
+        } else
+#endif /* __COVERITY__ */
+        {
             const t_dp_transition* pTT =
             dp_trans_table[ dp_state ] + trans_evt;
             nxtSt = pTT->next_state;
