@@ -1,9 +1,8 @@
 
 /*
- *  $Id: expGuile.c,v 4.18 2009/01/01 16:51:42 bkorb Exp $
+ *  $Id: 894017c5ed9c76c4c797d6d60cb977c575f946d5 $
  *
- *  Time-stamp:        "2007-07-04 11:19:05 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:51:42 $
+ *  Time-stamp:        "2009-09-27 08:32:09 bkorb"
  *
  *  This module implements the expression functions that should
  *  be part of Guile.
@@ -143,7 +142,7 @@ ag_scm_max( SCM list )
         return SCM_UNDEFINED;
 
     while (--len >= 0) {
-        unsigned long val;
+        long val;
 
         car  = SCM_CAR( list );
         list = SCM_CDR( list );
@@ -162,7 +161,7 @@ ag_scm_max( SCM list )
             break;
 
         case GH_TYPE_NUMBER:
-            val = gh_scm2ulong( car );
+            val = gh_scm2long( car );
             break;
 
         case GH_TYPE_STRING:
@@ -203,7 +202,7 @@ ag_scm_min( SCM list )
         return SCM_UNDEFINED;
 
     while (--len >= 0) {
-        unsigned long val;
+        long val;
 
         car  = SCM_CAR( list );
         list = SCM_CDR( list );
@@ -222,7 +221,7 @@ ag_scm_min( SCM list )
             break;
 
         case GH_TYPE_NUMBER:
-            val = gh_scm2ulong( car );
+            val = gh_scm2long( car );
             break;
 
         case GH_TYPE_STRING:
@@ -270,7 +269,7 @@ ag_scm_sum( SCM list )
             break;
 
         case GH_TYPE_NUMBER:
-            sum += gh_scm2ulong( car );
+            sum += gh_scm2long( car );
             break;
 
         case GH_TYPE_STRING:
