@@ -1,9 +1,8 @@
 
 /*
- *  $Id: expOutput.c,v 4.33 2009/07/21 03:21:57 bkorb Exp $
+ *  $Id: 1c97dc5ed8495653af850423a4c24b7105aac1df $
  *
- *  Time-stamp:        "2009-07-09 19:01:51 bkorb"
- *  Last Committed:    $Date: 2009/07/21 03:21:57 $
+ *  Time-stamp:        "2009-10-04 09:34:09 bkorb"
  *
  *  This module implements the output file manipulation function
  *
@@ -331,7 +330,7 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
             if (strcmp( pSuspended[ ix ].pzSuspendName, pzName ) == 0) {
                 tFpStack* pSaveFp = pCurFp;
                 pCurFp = pSuspended[ ix ].pOutDesc;
-                (void) ag_scm_emit( res );
+                (void) ag_scm_emit(res);
                 pCurFp = pSaveFp;
                 return SCM_UNDEFINED;
             }
@@ -343,7 +342,7 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
      *  "0" (zero) representing the current output and "1" the last suspended
      *  output.  If the number is out of range, we'll fall through to the abend.
      */
-    else if (AG_SCM_NUM_P(port)) do {
+    else if (AG_SCM_NUM_P(port)) {
         tFpStack* pSaveFp = pCurFp;
         unsigned long val = gh_scm2ulong(port);
 
@@ -355,17 +354,17 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
             }
         }
 
-        (void) ag_scm_emit( res );
+        (void) ag_scm_emit(res);
         pCurFp  = pSaveFp;
         return SCM_UNDEFINED;
-
-    fprintf_woops: ;
-    } while (0);
+    }
 
     /*
      *  Still here?  We have a bad "port" specification.
      */
-    AG_ABEND( invalid_z );
+    fprintf_woops:
+
+    AG_ABEND(invalid_z);
     /* NOTREACHED */
     return SCM_UNDEFINED;
 }
@@ -630,64 +629,64 @@ ag_scm_out_line( void )
     return AG_SCM_INT2SCM( lineNum );
 }
 
-#if 0
+#if 0 /* for compilers that do not like C++ comments... */
 // /*=gfunc   make_header_guard
- *
- * what:   make self-inclusion guard
- *
- * exparg: name , header group name
- *
- * doc:
- *   This function will create a @code{#ifndef}/@code{#define}
- *   sequence for protecting a header from multiple evaluation.
- *   It will also set the Scheme variable @code{header-file}
- *   to the name of the file being protected and it will set
- *   @code{header-guard} to the name of the @code{#define} being
- *   used to protect it.  It is expected that this will be used
- *   as follows:
- *   @example
- *   [+ (make-header-guard "group_name") +]
- *   ...
- *   #endif /* [+ (. header-guard) +] */
- *
- *   #include "[+ (. header-file)  +]"
- *   @end example
- *   @noindent
- *   The @code{#define} name is composed as follows:
- *
- *   @enumerate
- *   @item
- *   The first element is the string argument and a separating underscore.
- *   @item
- *   That is followed by the name of the header file with illegal
- *   characters mapped to underscores.
- *   @item
- *   The end of the name is always, "@code{_GUARD}".
- *   @item
- *   Finally, the entire string is mapped to upper case.
- *   @end enumerate
- *
- *   The final @code{#define} name is stored in an SCM symbol named
- *   @code{header-guard}.  Consequently, the concluding @code{#endif} for the
- *   file should read something like:
- *
- *   @example
- *   #endif /* [+ (. header-guard) +] */
- *   @end example
- *
- *   The name of the header file (the current output file) is also stored
- *   in an SCM symbol, @code{header-file}.  Therefore, if you are also
- *   generating a C file that uses the previously generated header file,
- *   you can put this into that generated file:
- *
- *   @example
- *   #include "[+ (. header-file) +]"
- *   @end example
- *
- *   Obviously, if you are going to produce more than one header file from
- *   a particular template, you will need to be careful how these SCM symbols
- *   get handled.
-=*/
+//  *
+//  * what:   make self-inclusion guard
+//  *
+//  * exparg: name , header group name
+//  *
+//  * doc:
+//  * This function will create a @code{#ifndef}/@code{#define}
+//  * sequence for protecting a header from multiple evaluation.
+//  * It will also set the Scheme variable @code{header-file}
+//  * to the name of the file being protected and it will set
+//  * @code{header-guard} to the name of the @code{#define} being
+//  * used to protect it.  It is expected that this will be used
+//  * as follows:
+//  * @example
+//  * [+ (make-header-guard "group_name") +]
+//  * ...
+//  * #endif /* [+ (. header-guard) +] */
+//  *
+//  * #include "[+ (. header-file)  +]"
+//  * @end example
+//  * @noindent
+//  * The @code{#define} name is composed as follows:
+//  *
+//  * @enumerate
+//  * @item
+//  * The first element is the string argument and a separating underscore.
+//  * @item
+//  * That is followed by the name of the header file with illegal
+//  * characters mapped to underscores.
+//  * @item
+//  * The end of the name is always, "@code{_GUARD}".
+//  * @item
+//  * Finally, the entire string is mapped to upper case.
+//  * @end enumerate
+//  *
+//  * The final @code{#define} name is stored in an SCM symbol named
+//  * @code{header-guard}.  Consequently, the concluding @code{#endif} for the
+//  * file should read something like:
+//  *
+//  * @example
+//  * #endif /* [+ (. header-guard) +] */
+//  * @end example
+//  *
+//  * The name of the header file (the current output file) is also stored
+//  * in an SCM symbol, @code{header-file}.  Therefore, if you are also
+//  * generating a C file that uses the previously generated header file,
+//  * you can put this into that generated file:
+//  *
+//  * @example
+//  * #include "[+ (. header-file) +]"
+//  * @end example
+//  *
+//  * Obviously, if you are going to produce more than one header file from
+//  * a particular template, you will need to be careful how these SCM symbols
+//  * get handled.
+// =*/
 #endif
 SCM
 ag_scm_make_header_guard(SCM name)
