@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sat Aug  8 10:14:57 PDT 2009
+ * Generated Sun Nov  8 08:41:21 PST 2009
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -132,6 +132,9 @@ freeEntry( tDefEntry* pDE );
 LOCAL tDefEntry*
 getEntry( void );
 
+LOCAL void
+print_def(tDefEntry * pDef);
+
 LOCAL tDefEntry*
 findPlace( char* name, tCC* pzIndex );
 
