@@ -1,9 +1,8 @@
 
-;;; Time-stamp:        "2007-07-04 11:51:37 bkorb"
-;;; Last Committed:    $Date: 2007/07/04 20:51:12 $
+;;; Time-stamp:        "2009-07-22 18:58:09 bkorb"
 ;;;
 ;;; This file is part of AutoGen.
-;;; AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+;;; AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
 ;;;
 ;;; AutoGen is free software: you can redistribute it and/or modify it
 ;;; under the terms of the GNU General Public License as published by the
@@ -95,11 +94,7 @@
 (define make-tmp-dir
   (lambda () 
     (begin (if (= tmp-dir "") (set! tmp-dir (shell
-  "tmp_dir=`mktemp -d ${TMPDIR:-.}/.ag-XXXXXX` 2>/dev/null
-  test -d \"${tmp_dir}\" || {
-    tmp_dir=${TMPDIR:-.}/.ag-$$
-    mkdir ${tmp_dir} || die cannot mkdir ${tmp_dir}
-  } ; echo ${tmp_dir}" ))))
+  "mk_tmp_dir ; echo ${tmp_dir}" ))))
 
   (add-cleanup (string-append
    "test \"${VERBOSE:-false}\" = true || rm -rf " tmp-dir))
