@@ -1,11 +1,10 @@
 /*
  *  agTempl.c
- *  $Id: tpProcess.c,v 4.23 2009/01/01 16:51:44 bkorb Exp $
+ *  $Id: 3ba9563a24d217b0f13ef2d4466a3dae57a57e7e $
  *
  *  Parse and process the template data descriptions
  *
- * Time-stamp:        "2007-11-10 15:55:33 bkorb"
- * Last Committed:    $Date: 2009/01/01 16:51:44 $
+ * Time-stamp:        "2009-11-01 14:09:38 bkorb"
  *
  * This file is part of AutoGen.
  * AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
@@ -110,12 +109,7 @@ doStdoutTemplate( tTemplate* pTF )
         return;
 
     default:
-        if (*pzOopsPrefix != NUL) {
-            fprintf( stdout, zBadR, pzOopsPrefix );
-            pzOopsPrefix = zNil;
-        } else {
-            fprintf( pfTrace, zBadR+2 );
-        }
+        fprintf(stdout, zBadR, pzOopsPrefix);
 
     case FAILURE:
         exit( EXIT_FAILURE );
@@ -165,17 +159,6 @@ LOCAL tOutSpec *
 nextOutSpec(tOutSpec * pOS)
 {
     tOutSpec * res = pOS->pNext;
-    /*
-     *  The format is either something inside of zFileFormat, we did not
-     *  allocate it.  If it is specifically zSuffix + strlen + 1, then
-     *  is it part of the pOS allocation.  Otherwise, we deallocate it.
-     */
-    if ((pOS->pzFileFmt < zFileFormat) ||
-        (pOS->pzFileFmt >= zFileFormat + sizeof(zFileFormat))) {
-        char const * pz = pOS->zSuffix + strlen(pOS->zSuffix) + 1;
-        if (pOS->pzFileFmt != pz)
-            AGFREE(pOS->pzFileFmt);
-    }
 
     if (pOS->deallocFmt)
         AGFREE(pOS->pzFileFmt);
@@ -323,6 +306,11 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
 {
     tCC*  pzDefFile;
 
+    /*
+     *  Reset the post-output control flags.
+     */
+    pStk->flags = 0;
+
     /*
      *  Figure out what to use as the base name of the output file.
      *  If an argument is not provided, we use the base name of
@@ -337,6 +325,8 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
         char   z[ AG_PATH_MAX ];
         tCC*   pS = strrchr( pzDefFile, '/' );
         char*  pE;
+
+        // coverity[dereference] -- invalid analysis -- "pS" not dereferenced.
         if (pS++ == NULL)
             pS = pzDefFile;
 
