@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for getdefs
- * Generated Sat May 24 10:45:59 PDT 2008
+ * Generated Sun Nov  8 08:41:19 PST 2009
  */
 #ifndef GETDEFS_PROTO_H_GUARD
 #define GETDEFS_PROTO_H_GUARD 1
@@ -21,6 +21,12 @@ emitDefinition( char* pzDef, char* pzOut );
 /*
  *  Extracted from gdinit.c
  */
+LOCAL void
+die(char const * fmt, ...);
+
+LOCAL void
+fserr_die(char const * fmt, ...);
+
 LOCAL void
 processEmbeddedOptions( char* pzText );
 
